@@ -270,13 +270,16 @@ void download_file(void)
 	if (GetServerStatus(Buf, NULL) == 2) {
 		StrBufCutLeft(Buf, 4);
 		bytes = StrBufExtract_long(Buf, 0, '|');
-		if (!force_download) {
-			StrBufExtract_token(ContentType, Buf, 3, '|');
-		}
-		serv_read_binary(WCC->WBuf, bytes, Buf);
+		StrBufExtract_token(ContentType, Buf, 3, '|');
+
+		CheckGZipCompressionAllowed (SKEY(ContentType));
+		if (force_download)
+			FlushStrBuf(ContentType);
+
+		serv_read_binary_to_http(ContentType, bytes, 0, 0);
 		serv_puts("CLOS");
 		StrBuf_ServGetln(Buf);
-		http_transmit_thing(ChrPtr(ContentType), 0);
+//		http_transmit_thing(ChrPtr(ContentType), 0);
 	} else {
 		StrBufCutLeft(Buf, 4);
 		hprintf("HTTP/1.1 404 %s\n", ChrPtr(Buf));
@@ -397,6 +400,7 @@ void output_image(void)
 			/** Write it to the browser */
 			if (!IsEmptyStr(MimeType))
 			{
+				CheckGZipCompressionAllowed (MimeType, strlen(MimeType));
 				http_transmit_thing(MimeType, 0);
 				FreeStrBuf(&Buf);
 				return;
