@@ -15,6 +15,8 @@
 #include "webcit.h"
 #include "webserver.h"
 
+CtxType CTX_ROOMS = CTX_NONE;
+CtxType CTX_FLOORS = CTX_NONE;
 
 /*
  * Embed the room banner
@@ -61,7 +63,7 @@ void tmplput_roombanner(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_FLOOR_ID(StrBuf *Target, WCTemplputParams *TP) 
 {
-	Floor *myFloor = (Floor *)CTX;
+	Floor *myFloor = (Floor *)CTX(CTX_FLOORS);
 
 	StrBufAppendPrintf(Target, "%d", myFloor->ID);
 }
@@ -69,14 +71,14 @@ void tmplput_FLOOR_ID(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_ROOM_FLOORID(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 	StrBufAppendPrintf(Target, "%d", Folder->floorid);
 }
 
 
 void tmplput_ROOM_FLOOR_ID(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 	const Floor *pFloor = Folder->Floor;
 
 	if (pFloor == NULL)
@@ -88,7 +90,7 @@ void tmplput_ROOM_FLOOR_ID(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_ROOM_FLOOR_NAME(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 	const Floor *pFloor = Folder->Floor;
 
 	if (pFloor == NULL)
@@ -117,7 +119,7 @@ void tmplput_ThisRoomFloorName(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_FLOOR_NAME(StrBuf *Target, WCTemplputParams *TP) 
 {
-	Floor *myFloor = (Floor *)CTX;
+	Floor *myFloor = (Floor *)CTX(CTX_FLOORS);
 
 	StrBufAppendTemplate(Target, TP, myFloor->Name, 0);
 }
@@ -125,7 +127,7 @@ void tmplput_FLOOR_NAME(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_FLOOR_NROOMS(StrBuf *Target, WCTemplputParams *TP) 
 {
-	Floor *myFloor = (Floor *)CTX;
+	Floor *myFloor = (Floor *)CTX(CTX_FLOORS);
 
 	StrBufAppendPrintf(Target, "%d", myFloor->NRooms);
 }
@@ -133,7 +135,7 @@ void tmplput_FLOOR_NROOMS(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_ROOM_FLOOR_NROOMS(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 	const Floor *pFloor = Folder->Floor;
 
 	if (pFloor == NULL)
@@ -144,7 +146,7 @@ void tmplput_ROOM_FLOOR_NROOMS(StrBuf *Target, WCTemplputParams *TP)
 
 int ConditionalFloorHaveNRooms(StrBuf *Target, WCTemplputParams *TP)
 {
-	Floor *MyFloor = (Floor *)CTX;
+	Floor *MyFloor = (Floor *)CTX(CTX_FLOORS);
 	int HaveN;
 
 	HaveN = GetTemplateTokenNumber(Target, TP, 0, 0);
@@ -156,7 +158,7 @@ int ConditionalFloorHaveNRooms(StrBuf *Target, WCTemplputParams *TP)
 int ConditionalFloorIsRESTSubFloor(StrBuf *Target, WCTemplputParams *TP)
 {
 	wcsession  *WCC = WC;
-	Floor *MyFloor = (Floor *)CTX;
+	Floor *MyFloor = (Floor *)CTX(CTX_FLOORS);
 	/** if we have dav_depth the client just wants the subfloors */
 	if ((WCC->Hdr->HR.dav_depth == 1) && 
 	    (GetCount(WCC->Directory) == 0))
@@ -168,7 +170,7 @@ int ConditionalFloorIsRESTSubFloor(StrBuf *Target, WCTemplputParams *TP)
 int ConditionalFloorIsSUBROOM(StrBuf *Target, WCTemplputParams *TP)
 {
 	wcsession  *WCC = WC;
-	Floor *MyFloor = (Floor *)CTX;
+	Floor *MyFloor = (Floor *)CTX(CTX_FLOORS);
 
 	return WCC->CurRoom.floorid == MyFloor->ID;
 }
@@ -176,7 +178,7 @@ int ConditionalFloorIsSUBROOM(StrBuf *Target, WCTemplputParams *TP)
 
 int ConditionalFloorIsVirtual(StrBuf *Target, WCTemplputParams *TP)
 {
-	Floor *MyFloor = (Floor *)CTX;
+	Floor *MyFloor = (Floor *)CTX(CTX_FLOORS);
 
 	return MyFloor->ID == VIRTUAL_MY_FLOOR;
 }
@@ -202,7 +204,7 @@ void tmplput_ThisRoom(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_ROOM_NAME(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 
 	StrBufAppendTemplate(Target, TP, Folder->name, 0);
 }
@@ -210,7 +212,7 @@ void tmplput_ROOM_NAME(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_ROOM_BASENAME(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *room = (folder *)CTX;
+	folder *room = (folder *)CTX(CTX_ROOMS);
 
 	if (room->nRoomNameParts > 1)
 		StrBufAppendTemplate(Target, TP, 
@@ -222,7 +224,7 @@ void tmplput_ROOM_BASENAME(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_ROOM_LEVEL_N_TIMES(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *room = (folder *)CTX;
+	folder *room = (folder *)CTX(CTX_ROOMS);
 	int i;
         const char *AppendMe;
         long AppendMeLen;
@@ -239,10 +241,27 @@ void tmplput_ROOM_LEVEL_N_TIMES(StrBuf *Target, WCTemplputParams *TP)
 
 int ConditionalRoomIsInbox(StrBuf *Target, WCTemplputParams *TP)
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 	return Folder->is_inbox;
 }
 
+int ConditionalRoomIsType(StrBuf *Target, WCTemplputParams *TP)
+{
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
+
+	if (Folder == NULL)
+		return 0;
+
+	if ((TP->Tokens->nParameters < 3))
+	{
+		return ((Folder->view < VIEW_BBS) || 
+			(Folder->view > VIEW_MAX));
+	}
+
+	return Folder->view == GetTemplateTokenNumber(Target, TP, 2, VIEW_BBS);
+}
+
+
 
 /****** Properties ******/
 int ConditionalRoom_MayEdit(StrBuf *Target, WCTemplputParams *TP)
@@ -295,7 +314,7 @@ int ConditionalRoomHas_QRFlag(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_ROOM_QRFLAGS(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 	StrBufAppendPrintf(Target, "%d", Folder->QRFlags);
 }
 
@@ -351,7 +370,7 @@ int ConditionalRoomHas_UAFlag(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_ROOM_ACL(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 
 	StrBufAppendPrintf(Target, "%ld", Folder->RAFlags, 0);
 }
@@ -459,7 +478,7 @@ int ConditionalThisRoomOrder(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_ROOM_LISTORDER(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 	StrBufAppendPrintf(Target, "%d", Folder->Order);
 }
 
@@ -516,7 +535,7 @@ void tmplput_ThisRoomInfoText(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_ROOM_LASTCHANGE(StrBuf *Target, WCTemplputParams *TP) 
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 	StrBufAppendPrintf(Target, "%d", Folder->lastchange);
 }
 
@@ -556,7 +575,7 @@ void tmplput_ThisRoomX_FileString(StrBuf *Target, WCTemplputParams *TP)
 
 int ConditionalIsThisThatRoom(StrBuf *Target, WCTemplputParams *TP)
 {
-	folder *Folder = (folder *)CTX;
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
 	wcsession *WCC = WC;
 
 	if (WCC == NULL)
@@ -565,11 +584,27 @@ int ConditionalIsThisThatRoom(StrBuf *Target, WCTemplputParams *TP)
 	return Folder == WCC->ThisRoom;
 }
 
+int ConditionalRoomIsName(StrBuf *Target, WCTemplputParams *TP)
+{
+	folder *Folder = (folder *)CTX(CTX_ROOMS);
+        const char *CheckRoomName = NULL;
+        long CheckRoomNameLen;
+
+	GetTemplateTokenString(Target, TP, 3, &CheckRoomName, &CheckRoomNameLen);
+	if (CheckRoomName == NULL)
+		return 0;
+	return strcmp(ChrPtr(Folder->name), CheckRoomName) == 0;
+}
+
 
 void 
 InitModule_ROOMTOKENS
 (void)
 {
+	/* we duplicate this, just to be shure its already done. */
+	RegisterCTX(CTX_ROOMS);
+	RegisterCTX(CTX_FLOORS);
+
 	RegisterNamespace("ROOMBANNER", 0, 1, tmplput_roombanner, NULL, CTX_NONE);
 
 	RegisterNamespace("FLOOR:ID", 0, 0, tmplput_FLOOR_ID, NULL, CTX_FLOORS);
@@ -583,10 +618,10 @@ InitModule_ROOMTOKENS
 	RegisterNamespace("FLOOR:NROOMS", 0, 0, tmplput_FLOOR_NROOMS, NULL, CTX_FLOORS);
 	RegisterNamespace("ROOM:INFO:FLOOR:NROOMS", 0, 0, tmplput_ROOM_FLOOR_NROOMS, NULL, CTX_ROOMS);
 
-	RegisterConditional(HKEY("COND:FLOOR:ISSUBROOM"), 0, ConditionalFloorIsSUBROOM, CTX_FLOORS);
-	RegisterConditional(HKEY("COND:FLOOR:NROOMS"), 1, ConditionalFloorHaveNRooms, CTX_FLOORS);
-	RegisterConditional(HKEY("COND:ROOM:REST:ISSUBFLOOR"), 0, ConditionalFloorIsRESTSubFloor, CTX_FLOORS);
-	RegisterConditional(HKEY("COND:FLOOR:ISVIRTUAL"), 0, ConditionalFloorIsVirtual, CTX_FLOORS);
+	RegisterConditional("COND:FLOOR:ISSUBROOM", 0, ConditionalFloorIsSUBROOM, CTX_FLOORS);
+	RegisterConditional("COND:FLOOR:NROOMS", 1, ConditionalFloorHaveNRooms, CTX_FLOORS);
+	RegisterConditional("COND:ROOM:REST:ISSUBFLOOR", 0, ConditionalFloorIsRESTSubFloor, CTX_FLOORS);
+	RegisterConditional("COND:FLOOR:ISVIRTUAL", 0, ConditionalFloorIsVirtual, CTX_FLOORS);
 
 	/**** Room... ******/
         /**** Name ******/
@@ -595,24 +630,26 @@ InitModule_ROOMTOKENS
 	RegisterNamespace("ROOM:INFO:NAME", 0, 1, tmplput_ROOM_NAME, NULL, CTX_ROOMS);
 	RegisterNamespace("ROOM:INFO:BASENAME", 0, 1, tmplput_ROOM_BASENAME, NULL, CTX_ROOMS);
 	RegisterNamespace("ROOM:INFO:LEVELNTIMES", 1, 2, tmplput_ROOM_LEVEL_N_TIMES, NULL, CTX_ROOMS);
-	RegisterConditional(HKEY("COND:ROOM:INFO:IS_INBOX"), 0, ConditionalRoomIsInbox, CTX_ROOMS);
+	RegisterConditional("COND:ROOM:INFO:IS_INBOX", 0, ConditionalRoomIsInbox, CTX_ROOMS);
+	RegisterConditional("COND:ROOM:INFO:TYPE_IS", 0, ConditionalRoomIsType, CTX_ROOMS);
+	RegisterConditional("COND:ROOM:INFO:NAME_IS", 1, ConditionalRoomIsName, CTX_ROOMS);
 
 	/****** Properties ******/
 	RegisterNamespace("ROOM:INFO:QRFLAGS", 0, 1, tmplput_ROOM_QRFLAGS, NULL, CTX_ROOMS);
-	RegisterConditional(HKEY("COND:THISROOM:FLAG:QR"), 0, ConditionalThisRoomHas_QRFlag, CTX_NONE);
-	RegisterConditional(HKEY("COND:THISROOM:EDIT"), 0, ConditionalRoom_MayEdit, CTX_NONE);
-	RegisterConditional(HKEY("COND:ROOM:FLAG:QR"), 0, ConditionalRoomHas_QRFlag, CTX_ROOMS);
+	RegisterConditional("COND:THISROOM:FLAG:QR", 0, ConditionalThisRoomHas_QRFlag, CTX_NONE);
+	RegisterConditional("COND:THISROOM:EDIT", 0, ConditionalRoom_MayEdit, CTX_NONE);
+	RegisterConditional("COND:ROOM:FLAG:QR", 0, ConditionalRoomHas_QRFlag, CTX_ROOMS);
 
-	RegisterConditional(HKEY("COND:THISROOM:FLAG:QR2"), 0, ConditionalThisRoomHas_QRFlag2, CTX_NONE);
-	RegisterConditional(HKEY("COND:ROOM:FLAG:QR2"), 0, ConditionalRoomHas_QRFlag2, CTX_ROOMS);
+	RegisterConditional("COND:THISROOM:FLAG:QR2", 0, ConditionalThisRoomHas_QRFlag2, CTX_NONE);
+	RegisterConditional("COND:ROOM:FLAG:QR2", 0, ConditionalRoomHas_QRFlag2, CTX_ROOMS);
 
-	RegisterConditional(HKEY("COND:ROOM:FLAG:UA"), 0, ConditionalRoomHas_UAFlag, CTX_ROOMS);
+	RegisterConditional("COND:ROOM:FLAG:UA", 0, ConditionalRoomHas_UAFlag, CTX_ROOMS);
 	RegisterNamespace("ROOM:INFO:RAFLAGS", 0, 1, tmplput_ROOM_RAFLAGS, NULL, CTX_ROOMS);
 
 
 	RegisterNamespace("ROOM:INFO:LISTORDER", 0, 1, tmplput_ROOM_LISTORDER, NULL, CTX_ROOMS);
 	RegisterNamespace("THISROOM:ORDER", 0, 0, tmplput_ThisRoomOrder, NULL, CTX_NONE);
-	RegisterConditional(HKEY("COND:THISROOM:ORDER"), 0, ConditionalThisRoomOrder, CTX_NONE);
+	RegisterConditional("COND:THISROOM:ORDER", 0, ConditionalThisRoomOrder, CTX_NONE);
 
 	RegisterNamespace("ROOM:INFO:LASTCHANGE", 0, 1, tmplput_ROOM_LASTCHANGE, NULL, CTX_ROOMS);
 
@@ -621,19 +658,19 @@ InitModule_ROOMTOKENS
 
 	RegisterNamespace("THISROOM:PASS", 0, 1, tmplput_ThisRoomPass, NULL, CTX_NONE);
 	RegisterNamespace("THISROOM:AIDE", 0, 1, tmplput_ThisRoomAide, NULL, CTX_NONE);
-	RegisterConditional(HKEY("COND:ROOMAIDE"), 2, ConditionalRoomAide, CTX_NONE);
-	RegisterConditional(HKEY("COND:ACCESS:DELETE"), 2, ConditionalRoomAcessDelete, CTX_NONE);
-	RegisterConditional(HKEY("COND:ROOM:EDITACCESS"), 0, ConditionalHaveRoomeditRights, CTX_NONE);
+	RegisterConditional("COND:ROOMAIDE", 2, ConditionalRoomAide, CTX_NONE);
+	RegisterConditional("COND:ACCESS:DELETE", 2, ConditionalRoomAcessDelete, CTX_NONE);
+	RegisterConditional("COND:ROOM:EDITACCESS", 0, ConditionalHaveRoomeditRights, CTX_NONE);
 
-	RegisterConditional(HKEY("COND:THISROOM:HAVE_PIC"), 0, ConditionalThisRoomXHavePic, CTX_NONE);
+	RegisterConditional("COND:THISROOM:HAVE_PIC", 0, ConditionalThisRoomXHavePic, CTX_NONE);
 
 	RegisterNamespace("THISROOM:INFOTEXT", 1, 2, tmplput_ThisRoomInfoText, NULL, CTX_NONE);
-	RegisterConditional(HKEY("COND:THISROOM:HAVE_INFOTEXT"), 0, ConditionalThisRoomXHaveInfoText, CTX_NONE);
+	RegisterConditional("COND:THISROOM:HAVE_INFOTEXT", 0, ConditionalThisRoomXHaveInfoText, CTX_NONE);
 
 	RegisterNamespace("THISROOM:FILES:N", 0, 1, tmplput_ThisRoomXNFiles, NULL, CTX_NONE);
 	RegisterNamespace("THISROOM:FILES:STR", 0, 1, tmplput_ThisRoomX_FileString, NULL, CTX_NONE);
 	RegisterNamespace("THISROOM:DIRECTORY", 0, 1, tmplput_ThisRoomDirectory, NULL, CTX_NONE);
 
 	RegisterNamespace("ROOM:INFO:ACL", 0, 1, tmplput_ROOM_ACL, NULL, CTX_ROOMS);
-	RegisterConditional(HKEY("COND:THIS:THAT:ROOM"), 0, ConditionalIsThisThatRoom, CTX_ROOMS);
+	RegisterConditional("COND:THIS:THAT:ROOM", 0, ConditionalIsThisThatRoom, CTX_ROOMS);
 }
