@@ -1,8 +1,8 @@
 <??("COND:BSTR", 1, "frame")>
 <?=("head")>
-<?=("important_msg")><?%("COND:LOGGEDIN", 1, 1, 1, "", ="paging")>
+<?%("COND:LOGGEDIN", 1, 1, 1, "", ="paging")>
 
-<div id="banner"><h1><?_("Pictures in")> <?ROOM:NAME></h1></div>
+<div id="banner"><h1><?_("Pictures in")> <?THISROOM:NAME></h1></div>
 <div id="content" class="service">
 	<table class="downloads_background">
 	<tr><td>
@@ -31,4 +31,4 @@
 	<th></th>
 	</table>
 <?=("trailing")>
-<??("X", 1)>
\ No newline at end of file
+<??("X", 1)>
