@@ -456,6 +456,297 @@ int serv_read_binary(StrBuf *Ret, size_t total_len, StrBuf *Buf)
 }
 
 
+int client_write(StrBuf *ThisBuf)
+{
+	wcsession *WCC = WC;
+        const char *ptr, *eptr;
+        long count;
+	ssize_t res = 0;
+        fd_set wset;
+        int fdflags;
+
+	ptr = ChrPtr(ThisBuf);
+	count = StrLength(ThisBuf);
+	eptr = ptr + count;
+
+	fdflags = fcntl(WC->Hdr->http_sock, F_GETFL);
+
+        while ((ptr < eptr) && (WCC->Hdr->http_sock != -1)) {
+                if ((fdflags & O_NONBLOCK) == O_NONBLOCK) {
+                        FD_ZERO(&wset);
+                        FD_SET(WCC->Hdr->http_sock, &wset);
+                        if (select(WCC->Hdr->http_sock + 1, NULL, &wset, NULL, NULL) == -1) {
+                                syslog(LOG_INFO, "client_write: Socket select failed (%s)\n", strerror(errno));
+                                return -1;
+                        }
+                }
+
+                if ((WCC->Hdr->http_sock == -1) || 
+		    ((res = write(WCC->Hdr->http_sock, ptr, count)),
+		     (res == -1)))
+		{
+                        syslog(LOG_INFO, "client_write: Socket write failed (%s)\n", strerror(errno));
+			wc_backtrace(LOG_INFO);
+                        return -1;
+                }
+                count -= res;
+		ptr += res;
+        }
+	return 0;
+}
+
+
+int
+read_serv_chunk(
+
+	StrBuf *Buf,
+	size_t total_len,
+	size_t *bytes_read
+	)
+{
+	int rc;
+	int ServerRc;
+	wcsession *WCC = WC;
+
+	serv_printf("READ "SIZE_T_FMT"|"SIZE_T_FMT, *bytes_read, total_len-(*bytes_read));
+	if ( (rc = StrBuf_ServGetln(Buf) > 0) &&
+	     (ServerRc = GetServerStatus(Buf, NULL), ServerRc == 6) ) 
+	{
+		size_t this_block = 0;
+
+		if (rc < 0)
+			return rc;
+
+		StrBufCutLeft(Buf, 4);
+		this_block = StrTol(Buf);
+		rc = StrBuf_ServGetBLOBBuffered(WCC->WBuf, this_block);
+		if (rc < 0) {
+			syslog(LOG_INFO, "Server connection broken during download\n");
+			wc_backtrace(LOG_INFO);
+			if (WCC->serv_sock > 0) close(WCC->serv_sock);
+			WCC->serv_sock = (-1);
+			WCC->connected = 0;
+			WCC->logged_in = 0;
+			return rc;
+		}
+		*bytes_read += rc;
+	}
+	return 6;
+}
+
+static inline int send_http(StrBuf *Buf)
+{
+#ifdef HAVE_OPENSSL
+	if (is_https)
+		return client_write_ssl(Buf);
+	else
+#endif
+		return client_write(Buf);
+}
+/*
+ * Read binary data from server into memory using a series of server READ commands.
+ * returns the read content as StrBuf
+ */
+void serv_read_binary_to_http(StrBuf *MimeType, size_t total_len, int is_static, int detect_mime)
+{
+	int ServerRc = 6;
+	wcsession *WCC = WC;
+	size_t bytes_read = 0;
+	int first = 1;
+	int client_con_state = 0;
+	int chunked = 0;
+	int is_gzip = 0;
+	const char *Err = NULL;
+	StrBuf *BufHeader = NULL;
+	StrBuf *Buf;
+	StrBuf *pBuf = NULL;
+	vStreamT *SC = NULL;
+	IOBuffer ReadBuffer;
+	IOBuffer WriteBuffer;
+	
+
+	Buf = NewStrBuf();
+
+	if (WCC->Hdr->HaveRange)
+	{
+		WCC->Hdr->HaveRange++;
+		WCC->Hdr->TotalBytes = total_len;
+		/* open range? or beyound file border? correct the numbers. */
+		if ((WCC->Hdr->RangeTil == -1) || (WCC->Hdr->RangeTil>= total_len))
+			WCC->Hdr->RangeTil = total_len - 1;
+		bytes_read = WCC->Hdr->RangeStart;
+		total_len = WCC->Hdr->RangeTil;
+	}
+	else
+		chunked = total_len > SIZ * 10; /* TODO: disallow for HTTP / 1.0 */
+
+	if (chunked)
+	{
+		BufHeader = NewStrBuf();
+	}
+
+	if ((detect_mime != 0) && (bytes_read != 0))
+	{
+		/* need to read first chunk to detect mime, though the client doesn't care */
+		size_t bytes_read = 0;
+		const char *CT;
+
+		ServerRc = read_serv_chunk(
+			Buf,
+			total_len,
+			&bytes_read);
+
+		if (ServerRc != 6)
+		{
+			FreeStrBuf(&BufHeader);
+			FreeStrBuf(&Buf);
+			return;
+		}
+		CT = GuessMimeType(SKEY(WCC->WBuf));
+		FlushStrBuf(WCC->WBuf);
+		StrBufPlain(MimeType, CT, -1);
+		CheckGZipCompressionAllowed(SKEY(MimeType));
+		detect_mime = 0;
+		FreeStrBuf(&Buf);
+	}
+
+	memset(&WriteBuffer, 0, sizeof(IOBuffer));
+	if (chunked && !DisableGzip && WCC->Hdr->HR.gzip_ok)
+	{
+		is_gzip = 1;
+		SC = StrBufNewStreamContext (eZLibEncode, &Err);
+		if (SC == NULL) {
+			syslog(LOG_ERR, "Error while initializing stream context: %s", Err);
+			FreeStrBuf(&Buf);
+			return;
+		}
+
+		memset(&ReadBuffer, 0, sizeof(IOBuffer));
+		ReadBuffer.Buf = WCC->WBuf;
+
+		WriteBuffer.Buf = NewStrBufPlain(NULL, SIZ*2);;
+		pBuf = WriteBuffer.Buf;
+	}
+	else
+	{
+		pBuf = WCC->WBuf;
+	}
+
+	if (!detect_mime)
+	{
+		http_transmit_headers(ChrPtr(MimeType), is_static, chunked, is_gzip);
+		
+		if (send_http(WCC->HBuf) < 0)
+		{
+			FreeStrBuf(&Buf);
+			FreeStrBuf(&WriteBuffer.Buf);
+			FreeStrBuf(&BufHeader);
+			if (StrBufDestroyStreamContext(eZLibEncode, &SC, &Err) && Err) {
+				syslog(LOG_ERR, "Error while destroying stream context: %s", Err);
+			}
+			return;
+		}
+	}
+
+	while ((bytes_read < total_len) &&
+	       (ServerRc == 6) &&
+	       (client_con_state == 0))
+	{
+
+		if (WCC->serv_sock==-1) {
+			FlushStrBuf(WCC->WBuf); 
+			FreeStrBuf(&Buf);
+			FreeStrBuf(&WriteBuffer.Buf);
+			FreeStrBuf(&BufHeader);
+			StrBufDestroyStreamContext(eZLibEncode, &SC, &Err);
+			if (StrBufDestroyStreamContext(eZLibEncode, &SC, &Err) && Err) {
+				syslog(LOG_ERR, "Error while destroying stream context: %s", Err);
+			}
+			return;
+		}
+
+		ServerRc = read_serv_chunk(
+			Buf,
+			total_len,
+			&bytes_read);
+		if (ServerRc != 6)
+			break;
+
+		if (detect_mime)
+		{
+			const char *CT;
+			detect_mime = 0;
+			
+			CT = GuessMimeType(SKEY(WCC->WBuf));
+			StrBufPlain(MimeType, CT, -1);
+			if (is_gzip) {
+				CheckGZipCompressionAllowed(SKEY(MimeType));
+				is_gzip = WCC->Hdr->HR.gzip_ok;
+			}
+			http_transmit_headers(ChrPtr(MimeType), is_static, chunked, is_gzip);
+			
+			client_con_state = send_http(WCC->HBuf);
+		}
+
+		if (is_gzip)
+		{
+			int done = (bytes_read == total_len);
+			while ((IOBufferStrLength(&ReadBuffer) > 0) && (client_con_state == 0)) {
+				int rc;
+
+				do {
+					rc = StrBufStreamTranscode(eZLibEncode, &WriteBuffer, &ReadBuffer, NULL, -1, SC, done, &Err);
+
+					if (StrLength (pBuf) > 0) {
+						StrBufPrintf(BufHeader, "%s%x\r\n", 
+						     (first)?"":"\r\n",
+							     StrLength (pBuf));
+						first = 0;
+						client_con_state = send_http(BufHeader);
+						if (client_con_state == 0) {
+							client_con_state = send_http(pBuf);
+						}
+						FlushStrBuf(pBuf);
+					}
+				} while ((rc == 1) && (StrLength(pBuf) > 0));
+			}
+			FlushStrBuf(WCC->WBuf);
+		}
+		else {
+			if ((chunked) && (client_con_state == 0))
+			{
+				StrBufPrintf(BufHeader, "%s%x\r\n", 
+					     (first)?"":"\r\n",
+					     StrLength (pBuf));
+				first = 0;
+				client_con_state = send_http(BufHeader);
+			}
+
+			if (client_con_state == 0)
+				client_con_state = send_http(pBuf);
+
+			FlushStrBuf(pBuf);
+		}
+	}
+
+	if (SC && StrBufDestroyStreamContext(eZLibEncode, &SC, &Err) && Err) {
+		syslog(LOG_ERR, "Error while destroying stream context: %s", Err);
+	}
+	FreeStrBuf(&WriteBuffer.Buf);
+	if ((chunked) && (client_con_state == 0))
+	{
+		StrBufPlain(BufHeader, HKEY("\r\n0\r\n\r\n"));
+		if (send_http(BufHeader) < 0)
+		{
+			FreeStrBuf(&Buf);
+		        FreeStrBuf(&BufHeader);
+			return;
+		}
+	}
+	FreeStrBuf(&BufHeader);
+	FreeStrBuf(&Buf);
+}
+
 int ClientGetLine(ParsedHttpHdrs *Hdr, StrBuf *Target)
 {
 	const char *Error;
@@ -863,7 +1154,7 @@ long end_burst(void)
 
 /*
  * lingering_close() a`la Apache. see
- * http://www.apache.org/docs/misc/fin_wait_2.html for rationale
+ * http://httpd.apache.org/docs/2.0/misc/fin_wait_2.html for rationale
  */
 int lingering_close(int fd)
 {
