@@ -13,7 +13,7 @@
 #include "webcit.h"
 #include "webserver.h"
 
-
+CtxType CTX_USERLIST = CTX_NONE;
 /*
  *  show a list of available users to edit them
  *  message the header message???
@@ -330,80 +330,80 @@ HashList *iterate_load_userlist(StrBuf *Target, WCTemplputParams *TP)
 
 void tmplput_USERLIST_UserName(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 	StrBufAppendTemplate(Target, TP, ul->UserName, 0);
 }
 
 void tmplput_USERLIST_Password(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 	StrBufAppendTemplate(Target, TP, ul->Passvoid, 0);
 }
 
 void tmplput_USERLIST_AccessLevelNo(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 
 	StrBufAppendPrintf(Target, "%d", ul->AccessLevel, 0);
 }
 
 void tmplput_USERLIST_AccessLevelStr(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 	
 	StrBufAppendBufPlain(Target, _(axdefs[ul->AccessLevel]), -1, 0);
 }
 
 void tmplput_USERLIST_UID(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 
 	StrBufAppendPrintf(Target, "%d", ul->UID, 0);
 }
 
 void tmplput_USERLIST_LastLogonNo(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 
 	StrBufAppendPrintf(Target,"%ld", ul->LastLogonT, 0);
 }
 void tmplput_USERLIST_LastLogonStr(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 	StrEscAppend(Target, NULL, asctime(localtime(&ul->LastLogonT)), 0, 0);
 }
 
 void tmplput_USERLIST_nLogons(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 
 	StrBufAppendPrintf(Target, "%d", ul->nLogons, 0);
 }
 
 void tmplput_USERLIST_nPosts(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 
 	StrBufAppendPrintf(Target, "%d", ul->nPosts, 0);
 }
 
 void tmplput_USERLIST_Flags(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 
 	StrBufAppendPrintf(Target, "%d", ul->Flags, 0);
 }
 
 void tmplput_USERLIST_DaysTillPurge(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 
 	StrBufAppendPrintf(Target, "%d", ul->DaysTillPurge, 0);
 }
 
 int ConditionalUser(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 	if (havebstr("usernum")) {
 		return ibstr("usernum") == ul->UID;
 	}
@@ -416,13 +416,13 @@ int ConditionalUser(StrBuf *Target, WCTemplputParams *TP)
 
 int ConditionalFlagINetEmail(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 	return (ul->Flags & US_INTERNET) != 0;
 }
 
 int ConditionalUserAccess(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 	
 	if (ul == NULL)
 		return 0;
@@ -436,7 +436,7 @@ int ConditionalUserAccess(StrBuf *Target, WCTemplputParams *TP)
 }
 int ConditionalHaveBIO(StrBuf *Target, WCTemplputParams *TP)
 {
-	UserListEntry *ul = (UserListEntry*) CTX;
+	UserListEntry *ul = (UserListEntry*) CTX(CTX_USERLIST);
 	
 	if (ul == NULL)
 		return 0;
@@ -806,6 +806,7 @@ void
 InitModule_USEREDIT
 (void)
 {
+	RegisterCTX(CTX_USERLIST);
 	WebcitAddUrlHandler(HKEY("select_user_to_edit"), "", 0, _select_user_to_edit, 0);
 	WebcitAddUrlHandler(HKEY("display_edituser"), "", 0, _display_edituser, 0);
 	WebcitAddUrlHandler(HKEY("edituser"), "", 0, edituser, 0);
@@ -826,12 +827,12 @@ InitModule_USEREDIT
 
 	RegisterNamespace("USER:BIO", 1, 2, tmplput_USER_BIO,  NULL, CTX_NONE);
 
-	RegisterConditional(HKEY("COND:USERNAME"),  0,    ConditionalUser, CTX_USERLIST);
-	RegisterConditional(HKEY("COND:USERACCESS"), 0,   ConditionalUserAccess, CTX_USERLIST);
-	RegisterConditional(HKEY("COND:USERLIST:FLAG:USE_INTERNET"), 0, ConditionalFlagINetEmail, CTX_USERLIST);
-	RegisterConditional(HKEY("COND:USERLIST:HAVEBIO"), 0, ConditionalHaveBIO, CTX_USERLIST);
+	RegisterConditional("COND:USERNAME",  0,    ConditionalUser, CTX_USERLIST);
+	RegisterConditional("COND:USERACCESS", 0,   ConditionalUserAccess, CTX_USERLIST);
+	RegisterConditional("COND:USERLIST:FLAG:USE_INTERNET", 0, ConditionalFlagINetEmail, CTX_USERLIST);
+	RegisterConditional("COND:USERLIST:HAVEBIO", 0, ConditionalHaveBIO, CTX_USERLIST);
 
-	RegisterConditional(HKEY("COND:USER:PIC"), 1, Conditional_USER_HAS_PIC,  CTX_NONE);
+	RegisterConditional("COND:USER:PIC", 1, Conditional_USER_HAS_PIC,  CTX_NONE);
 
 	RegisterIterator("USERLIST", 0, NULL, iterate_load_userlist, NULL, DeleteHash, CTX_USERLIST, CTX_NONE, IT_FLAG_DETECT_GROUPCHANGE);
 	
