@@ -14,7 +14,7 @@
 #include "webserver.h"
 #include "calendar.h"
 
-
+CtxType CTX_VCARD = CTX_NONE;
 
 ConstStr VCStr [] = {
 	{HKEY("n")}, /* N is name, but only if there's no FN already there */
@@ -137,7 +137,8 @@ wc_mime_attachment *load_vcard(message_summary *Msg)
 	if (VCMime == NULL)
 		return NULL;
 
-	MimeLoadData(VCMime);
+	if (VCMime->Data == NULL)
+		MimeLoadData(VCMime);
 	return VCMime;
 }
 
@@ -651,7 +652,7 @@ TODO: check for layer II
 
 void tmplput_VCARD_ITEM(StrBuf *Target, WCTemplputParams *TP)
 {
-	HashList *VC = CTX;
+	HashList *VC = CTX(CTX_VCARD);
 	eVC evc;
 	void *vStr;
 
@@ -1511,6 +1512,7 @@ void
 InitModule_VCARD
 (void)
 {
+	RegisterCTX(CTX_VCARD);
 	RegisterReadLoopHandlerset(
 		VIEW_ADDRESSBOOK,
 		vcard_GetParamsGetServerCall,
