@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1987-2013 by the citadel.org team
+ * Copyright (c) 1987-2015 by the citadel.org team
  *
  * This program is open source software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License version 3.
@@ -25,9 +25,6 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <sys/socket.h>
-#ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
-#endif
 #include <sys/stat.h>
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
@@ -64,8 +61,6 @@
 #define _(string)	(string)
 #endif
 
-#define IsEmptyStr(a) ((a)[0] == '\0')
-
 #define DO_DBG_QR 0
 #define DBG_QR(x) if(DO_DBG_QR) _DBG_QR(x)
 #define DBG_QR2(x) if(DO_DBG_QR) _DBG_QR2(x)
@@ -132,9 +127,9 @@ extern char *ssl_cipher_list;
 #define PORT_NUM		2000		/* port number to listen on */
 #define DEVELOPER_ID		0
 #define CLIENT_ID		4
-#define CLIENT_VERSION		824		/* This version of WebCit */
-#define MINIMUM_CIT_VERSION	824		/* Minimum required version of Citadel server */
-#define	LIBCITADEL_MIN		821		/* Minimum required version of libcitadel */
+#define CLIENT_VERSION		901		/* This version of WebCit */
+#define MINIMUM_CIT_VERSION	901		/* Minimum required version of Citadel server */
+#define	LIBCITADEL_MIN		901		/* Minimum required version of libcitadel */
 #define DEFAULT_HOST		"localhost"	/* Default Citadel server */
 #define DEFAULT_PORT		"504"
 #define TARGET			"webcit01"	/* Window target for inline URL's */
@@ -389,6 +384,10 @@ typedef struct _HdrRefs {
 
 typedef struct _ParsedHttpHdrs {
 	int http_sock;				/* HTTP server socket */
+	long HaveRange;
+	long RangeStart;
+	long RangeTil;
+	long TotalBytes;
 	const char *Pos;
 	StrBuf *ReadBuf;
 
@@ -564,7 +563,7 @@ void ssl_lock(int mode, int n, const char *file, int line);
 int starttls(int sock);
 extern SSL_CTX *ssl_ctx;  
 int client_read_sslbuffer(StrBuf *buf, int timeout);
-void client_write_ssl(const StrBuf *Buf);
+int client_write_ssl(const StrBuf *Buf);
 #endif
 
 extern int is_https;
@@ -581,6 +580,7 @@ void InitialiseSemaphores(void);
 void begin_critical_section(int which_one);
 void end_critical_section(int which_one);
 
+void CheckGZipCompressionAllowed(const char *MimeType, long MLen);
 
 extern void do_404(void);
 void http_redirect(const char *);
@@ -690,6 +690,7 @@ extern char *days[];
 long locate_user_vcard_in_this_room(message_summary **VCMsg,
 				    wc_mime_attachment **VCAtt);
 void http_transmit_thing(const char *content_type, int is_static);
+void http_transmit_headers(const char *content_type, int is_static, long is_chunked, int is_gzip);
 long unescape_input(char *buf);
 void check_thread_pool_size(void);
 void StrEndTab(StrBuf *Target, int tabnum, int num_tabs);
@@ -750,6 +751,7 @@ struct blogpost {
 	long *msgs;		/* Array of msgnums for messages we are displaying */
 	int num_msgs;		/* Number of msgnums stored in 'msgs' */
 	int alloc_msgs;		/* Currently allocated size of array */
+	int unread_oments;
 };
 
 
