@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996-2014 by the citadel.org team
+ * Copyright (c) 1996-2015 by the citadel.org team
  *
  * This program is open source software.  You can redistribute it and/or
  * modify it under the terms of the GNU General Public License version 3.
@@ -49,6 +49,7 @@ extern HashList *HandlerHash;
 const char foobuf[32];
 const char *nix(void *vptr) {snprintf(foobuf, 32, "%0x", (long) vptr); return foobuf;}
 #endif 
+extern int verbose;
 extern int dbg_analyze_msg;
 extern int dbg_backtrace_template_errors;
 extern int DumpTemplateI18NStrings;
@@ -56,6 +57,7 @@ extern StrBuf *I18nDump;
 void InitTemplateCache(void);
 extern int LoadTemplates;
 
+void LoadMimeBlacklist(void);
 
 /*
  * Here's where it all begins.
@@ -99,9 +101,9 @@ int main(int argc, char **argv)
 
 	/* Parse command line */
 #ifdef HAVE_OPENSSL
-	while ((a = getopt(argc, argv, "u:h:i:p:t:T:B:x:g:dD:G:cfsS:Z")) != EOF)
+	while ((a = getopt(argc, argv, "u:h:i:p:t:T:B:x:g:dD:G:cfsS:Z:v:")) != EOF)
 #else
-	while ((a = getopt(argc, argv, "u:h:i:p:t:T:B:x:g:dD:G:cfZ")) != EOF)
+	while ((a = getopt(argc, argv, "u:h:i:p:t:T:B:x:g:dD:G:cfZ:v:")) != EOF)
 #endif
 		switch (a) {
 		case 'u':
@@ -148,8 +150,8 @@ int main(int argc, char **argv)
 			break;
 		case 'T':
 			LoadTemplates = atoi(optarg);
-			dbg_analyze_msg = (LoadTemplates && (1<<1)) != 0;
-			dbg_backtrace_template_errors = (LoadTemplates && (1<<2)) != 0;
+			dbg_analyze_msg = (LoadTemplates & (1<<1)) != 0;
+			dbg_backtrace_template_errors = (LoadTemplates & (1<<2)) != 0;
 			break;
 		case 'Z':
 			DisableGzip = 1;
@@ -188,12 +190,18 @@ int main(int argc, char **argv)
 			I18nDump = NewStrBufPlain(HKEY("int templatestrings(void)\n{\n"));
 			I18nDumpFile = optarg;
 			break;
+		case 'v':
+			verbose=1;
+			break;
 		default:
-			fprintf(stderr, "usage: webcit "
+			fprintf(stderr, "usage:\nwebcit "
 				"[-i ip_addr] [-p http_port] "
 				"[-c] [-f] "
 				"[-T Templatedebuglevel] "
 				"[-d] [-Z] [-G i18ndumpfile] "
+				"[-u uid] [-h homedirectory] "
+				"[-D daemonizepid] [-v] "
+				"[-g defaultlandingpage] [-B basesize] "
 #ifdef HAVE_OPENSSL
 				"[-s] [-S cipher_suites]"
 #endif
@@ -223,11 +231,12 @@ int main(int argc, char **argv)
 	}
 
 	webcit_calc_dirs_n_files(relh, basedir, home, webcitdir, relhome);
+	LoadMimeBlacklist();
 	LoadIconDir(static_icon_dir);
 
 	/* Tell 'em who's in da house */
 	syslog(LOG_NOTICE, "%s", PACKAGE_STRING);
-	syslog(LOG_NOTICE, "Copyright (C) 1996-2014 by the citadel.org team");
+	syslog(LOG_NOTICE, "Copyright (C) 1996-2015 by the citadel.org team");
 	syslog(LOG_NOTICE, " ");
 	syslog(LOG_NOTICE, "This program is open source software: you can redistribute it and/or");
 	syslog(LOG_NOTICE, "modify it under the terms of the GNU General Public License, version 3.");
